==> qtjambi-opengl-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiOpenGL/QOpenGLWindow_shell.h <==
#ifndef QOPENGLWINDOW_SHELL_H
#define QOPENGLWINDOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtOpenGL/qopenglwindow.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qicon.h>
#include <QtGui/qimage.h>
#include <QtGui/qopenglcontext.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


class QOpenGLWindow_shell : public QOpenGLWindow, public QtJambiShellInterface
{
public:
    QOpenGLWindow_shell(QOpenGLContext* shareContext0, QOpenGLWindow::UpdateBehavior updateBehavior1 = QOpenGLWindow::NoPartialUpdate, QWindow* parent2 = nullptr);
    QOpenGLWindow_shell(QOpenGLWindow::UpdateBehavior updateBehavior0 = QOpenGLWindow::NoPartialUpdate, QWindow* parent1 = nullptr);
    ~QOpenGLWindow_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QOpenGLWindow_mshell;
    friend class QOpenGLWindow_oshell;
};


class QOpenGLWindow_mshell : public QOpenGLWindow_shell
{
public:
    using QOpenGLWindow_shell::QOpenGLWindow_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QOpenGLWindow_oshell : public QOpenGLWindow_mshell
{
public:
    using QOpenGLWindow_mshell::QOpenGLWindow_mshell;
    ~QOpenGLWindow_oshell() override;
    QAccessibleInterface* accessibleRoot() const override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* arg__1) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void exposeEvent(QExposeEvent* arg__1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    QObject* focusObject() const override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    QSurfaceFormat format() const override;
    void hideEvent(QHideEvent* arg__1) override;
    void initPainter(QPainter* painter0) const override;
    void initializeGL() override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* arg__1) override;
    int metric(QPaintDevice::PaintDeviceMetric metric0) const override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* arg__1) override;
    void paintEvent(QPaintEvent* event0) override;
    void paintGL() override;
    void paintOverGL() override;
    void paintUnderGL() override;
    QPaintDevice* redirected(QPoint* arg__1) const override;
    void resizeEvent(QResizeEvent* event0) override;
    void resizeGL(int w0, int h1) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void tabletEvent(QTabletEvent* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* arg__1) override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLWindow_access : public QOpenGLWindow
{
    void __qt_initializeGL(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint metric0) const;
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_paintGL(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_paintOverGL(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_paintUnderGL(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_resizeGL_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint w0, jint h1);
};

#endif // QOPENGLWINDOW_SHELL_H

==> qtjambi-opengl-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiOpenGL/QOpenGLWindow_shell.h <==
#ifndef QOPENGLWINDOW_SHELL_H
#define QOPENGLWINDOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtOpenGL/qopenglwindow.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qicon.h>
#include <QtGui/qimage.h>
#include <QtGui/qopenglcontext.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


class QOpenGLWindow_shell : public QOpenGLWindow, public QtJambiShellInterface
{
public:
    QOpenGLWindow_shell(QOpenGLContext* shareContext0, QOpenGLWindow::UpdateBehavior updateBehavior1 = QOpenGLWindow::NoPartialUpdate, QWindow* parent2 = nullptr);
    QOpenGLWindow_shell(QOpenGLWindow::UpdateBehavior updateBehavior0 = QOpenGLWindow::NoPartialUpdate, QWindow* parent1 = nullptr);
    ~QOpenGLWindow_shell() override;

    QAccessibleInterface* accessibleRoot() const override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* arg__1) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void exposeEvent(QExposeEvent* arg__1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    QObject* focusObject() const override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    QSurfaceFormat format() const override;
    void hideEvent(QHideEvent* arg__1) override;
    void initPainter(QPainter* painter0) const override;
    void initializeGL() override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* arg__1) override;
    int metric(QPaintDevice::PaintDeviceMetric metric0) const override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* arg__1) override;
    void paintEvent(QPaintEvent* event0) override;
    void paintGL() override;
    void paintOverGL() override;
    void paintUnderGL() override;
    QPaintDevice* redirected(QPoint* arg__1) const override;
    void resizeEvent(QResizeEvent* event0) override;
    void resizeGL(int w0, int h1) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void tabletEvent(QTabletEvent* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* arg__1) override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLWindow_access : public QOpenGLWindow
{
    void __qt_initializeGL(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint metric0) const;
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_paintGL(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_paintOverGL(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_paintUnderGL(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_resizeGL_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint w0, jint h1);
};

#endif // QOPENGLWINDOW_SHELL_H
